GoogleMapPolygonController class

Public controller shown to users of the package/app.

Properties

hashCode int
The hash code for this object.
no setterinherited
onPolygonCreated Stream<Map<String, dynamic>>
Listen for polygon created events (public stream)
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

clearPolygon() → void
Clear polygon from the map (public)
dispose() → void
Dispose controller resources
moveTo(double lat, double lng) → void
Move the map camera (public)
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited