LatLng class

Available extensions
Annotations

Constructors

LatLng(num lat, num lng)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
lat num

Available on LatLng, provided by the LatLngExtension extension

no setter
lng num

Available on LatLng, provided by the LatLngExtension extension

no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited