PolygonData class

Constructors

PolygonData({required String id, required List<LatLng> points, String fillColor = '#FF0000', double fillOpacity = 0.4})

Properties

fillColor String
final
fillOpacity double
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
points List<LatLng>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited