platform/google_map_script library

Functions

loadGoogleMapsScript(String apiKey) Future<void>
This function is used to load the Google Maps script manually because the Google map is causing issue on Web.