GoogleMapPolygon class

Inheritance

Constructors

GoogleMapPolygon({Key? key, required String mapId, required String mapKey, required GoogleMapPolygonController mapController, required CameraPosition initialCameraPosition, double mapHeight = 300, double mapWidth = double.infinity, List<PolygonData>? polygons, PolygonData? singlePolygon, bool returnAsWKT = false, void onPolygonCreated(dynamic value)?, bool editPolygon = false, void onPolygonEdited(dynamic value)?})

Properties

editPolygon bool
final
hashCode int
The hash code for this object.
no setterinherited
initialCameraPosition CameraPosition
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
mapController GoogleMapPolygonController
final
mapHeight double
final
mapId String
final
mapKey String
final
mapWidth double
final
onPolygonCreated → void Function(dynamic value)?
final
onPolygonEdited → void Function(dynamic value)?
final
polygons List<PolygonData>?
final
returnAsWKT bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
singlePolygon PolygonData?
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<GoogleMapPolygon>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited