menu
google_maps_polygon package
documentation
platform/google_map_script.dart
platform/google_map_script.dart
dark_mode
light_mode
platform/google_map_script
library
Functions
loadGoogleMapsScript
(
String
apiKey
)
→
Future
<
void
>
This function is used to load the Google Maps script manually because the Google map is causing issue on Web.
google_maps_polygon package
documentation
platform/google_map_script.dart
google_maps_polygon
package
Libraries
google_map_polygon
models/camera_position
models/lat_lng
models/polygon_data
platform/google_map_script
platform/web_only/web_only
widgets/google_map_polygon_widget
google_map_script library